@@ -1,9 +1,11 @@
+#ifdef THIS_CODE_IS_NOT_USED
 /*! ========================================================================
 ** Extended Template Library
 ** Status Callback Class Implementation
-** $Id: _status.h 334 2007-03-16 00:37:48Z dooglus $
+** $Id: _status.h 848 2007-10-06 02:25:36Z dooglus $
 **
 ** Copyright (c) 2002 Robert B. Quattlebaum Jr.
+** Copyright (c) 2007 Chris Moore
 **
 ** This package is free software; you can redistribute it and/or
 ** modify it under the terms of the GNU General Public License as
@@ -44,6 +46,7 @@ public:
 
 	virtual bool task(const std::string &task) { return true; }
 
+#warning this task(task) thing looks wrong, but the code isn't used, so let's not worry
 	virtual void push_task(const std::string &task,int start=0, int end=100, int total=100)
 		{ task(task); }
 	virtual void pop_task() { return; }
@@ -63,4 +66,4 @@ _ETL_END_NAMESPACE
 /* === E N D =============================================================== */
 
 #endif
-
+#endif /* THIS_CODE_IS_NOT_USED */
