@@ -1,7 +1,7 @@
 /*! ========================================================================
 ** Extended Template and Library Test Suite
 ** Angle Class Test
-** $Id: smach.cpp 334 2007-03-16 00:37:48Z dooglus $
+** $Id: smach.cpp 1514 2008-01-27 15:29:47Z dooglus $
 **
 ** Copyright (c) 2002 Robert B. Quattlebaum Jr.
 **
@@ -63,10 +63,10 @@ class DefaultStateContext
 {
 	MachineContext *context;
 public:
-	DefaultStateContext(MachineContext *context):context(context) { printf("Enterted Default State\n"); }
+	DefaultStateContext(MachineContext *context):context(context) { printf("Entered Default State\n"); }
 	~DefaultStateContext() { printf("Left Default State\n"); }
 
-	Smach::event_result event1_handler(const Smach::event& x)
+	Smach::event_result event1_handler(const Smach::event& x __attribute__ ((unused)))
 	{
 		printf("DEFAULT STATE: Received Event 1\n");
 		return Smach::RESULT_ACCEPT;
@@ -93,10 +93,10 @@ class State1Context
 {
 	MachineContext *context;
 public:
-	State1Context(MachineContext *context):context(context) { printf("Enterted State 1\n"); }
+	State1Context(MachineContext *context):context(context) { printf("Entered State 1\n"); }
 	~State1Context() { printf("Left State 1\n"); }
 
-	Smach::event_result event1_handler(const Smach::event& x)
+	Smach::event_result event1_handler(const Smach::event& x __attribute__ ((unused)))
 	{
 		printf("STATE1: Received Event 1\n");
 		return Smach::RESULT_OK;
@@ -121,22 +121,22 @@ class State2Context
 {
 	MachineContext *context;
 public:
-	State2Context(MachineContext *context):context(context) { printf("Enterted State 2\n"); }
+	State2Context(MachineContext *context):context(context) { printf("Entered State 2\n"); }
 	~State2Context() { printf("Left State 2\n"); }
 
-	Smach::event_result event1_handler(const Smach::event& x)
+	Smach::event_result event1_handler(const Smach::event& x __attribute__ ((unused)))
 	{
 		printf("STATE2: Received Event 1\n");
 		return Smach::RESULT_OK;
 	}
 
-	Smach::event_result event2_handler(const Smach::event& x)
+	Smach::event_result event2_handler(const Smach::event& x __attribute__ ((unused)))
 	{
 		printf("STATE2: Received Event 2\n");
 		return Smach::RESULT_OK;
 	}
 
-	Smach::event_result event3_handler(const Smach::event& x)
+	Smach::event_result event3_handler(const Smach::event& x __attribute__ ((unused)))
 	{
 		printf("STATE2: Received Event 3\n");
 		return Smach::RESULT_OK;
@@ -156,7 +156,7 @@ public:
 } state_2;
 
 Smach::event_result
-State1Context::event3_handler(const Smach::event& x)
+State1Context::event3_handler(const Smach::event& x __attribute__ ((unused)))
 {
 	printf("STATE1: Received Event 3, throwing state to change to...\n");
 
