@@ -1,7 +1,7 @@
 /*! ========================================================================
 ** Extended Template and Library Test Suite
 ** Smart Pointer Template Class Test
-** $Id: smart_ptr.cpp 334 2007-03-16 00:37:48Z dooglus $
+** $Id: smart_ptr.cpp 1514 2008-01-27 15:29:47Z dooglus $
 **
 ** Copyright (c) 2002 Robert B. Quattlebaum Jr.
 **
@@ -247,7 +247,7 @@ int smart_ptr_inheritance_test(void)
 	return 0;
 }
 
-void test_func(etl::smart_ptr<my_test_obj> smart_ptr)
+void test_func(etl::smart_ptr<my_test_obj> smart_ptr __attribute__ ((unused)))
 {
 }
 
